from ..General.GeneralClass import GeneralClass


class SubtractZValue(GeneralClass):
    def __init__(self) -> None:
        self.operationName: str = 'SubtractZValue'
        self.operationNumber: int = 19
