from ..General.GeneralClass import GeneralClass


class SubtractYValue(GeneralClass):
    def __init__(self) -> None:
        self.operationName: str = 'SubtractYValue'
        self.operationNumber: int = 17
